@@ -8,33 +8,24 @@
 
 """Handlers for customizing oauthclient endpoints."""
 
-from __future__ import absolute_import, print_function
-
-from functools import partial, wraps
-
-import six
-from flask import current_app, flash, redirect, render_template, request, \
-    session, url_for
-from flask_babelex import gettext as _
+from flask import current_app, session
 from flask_login import current_user
 from invenio_db import db
-from werkzeug.utils import import_string
+from pkg_resources import require
 
-from ..errors import AlreadyLinkedError, OAuthCERNRejectedAccountError, \
-    OAuthClientAlreadyAuthorized, OAuthClientError, \
+from ..errors import OAuthClientAlreadyAuthorized, \
     OAuthClientMustRedirectLogin, OAuthClientMustRedirectSignup, \
     OAuthClientTokenNotFound, OAuthClientTokenNotSet, \
-    OAuthClientUnAuthorized, OAuthClientUserNotRegistered, OAuthError, \
-    OAuthRejectedRequestError, OAuthResponseError
-from ..models import RemoteAccount, RemoteToken
+    OAuthClientUnAuthorized, OAuthClientUserNotRegistered
+from ..models import RemoteAccount
 from ..proxies import current_oauthclient
 from ..signals import account_info_received, account_setup_committed, \
     account_setup_received
-from ..utils import create_csrf_disabled_registrationform, \
-    create_registrationform, fill_form, oauth_authenticate, oauth_get_user, \
-    oauth_register
-from .utils import get_session_next_url, response_token_setter, token_getter, \
-    token_session_key, token_setter
+from ..utils import create_csrf_disabled_registrationform, fill_form, \
+    oauth_authenticate, oauth_get_user, oauth_register
+from .utils import get_session_next_url, \
+    require_more_than_one_external_account, response_token_setter, \
+    token_getter, token_session_key, token_setter
 
 
 #
@@ -73,12 +64,14 @@ def base_authorized_signup_handler(resp, remote, *args, **kwargs):
 
         if user is None:
             # Auto sign-up if user not found
-            form = create_csrf_disabled_registrationform()
+            form = create_csrf_disabled_registrationform(remote)
             form = fill_form(
                 form,
                 account_info['user']
             )
-            user = oauth_register(form)
+            remote_apps = current_app.config['OAUTHCLIENT_REMOTE_APPS']
+            precedence_mask = remote_apps[remote.name].get("precedence_mask")
+            user = oauth_register(form, account_info['user'], precedence_mask)
 
             # if registration fails ...
             if user is None:
@@ -121,6 +114,7 @@ def base_authorized_signup_handler(resp, remote, *args, **kwargs):
         return next_url
 
 
+@require_more_than_one_external_account
 def base_disconnect_handler(remote, *args, **kwargs):
     """Handle unlinking of remote account.
 
@@ -170,9 +164,11 @@ def base_signup_handler(remote, form, *args, **kwargs):
     if form.validate_on_submit():
         account_info = session.get(session_prefix + '_account_info')
         response = session.get(session_prefix + '_response')
+        remote_apps = current_app.config['OAUTHCLIENT_REMOTE_APPS']
+        precedence_mask = remote_apps[remote.name].get("precedence_mask")
 
         # Register user
-        user = oauth_register(form)
+        user = oauth_register(form, account_info['user'], precedence_mask)
 
         if user is None:
             raise OAuthClientUserNotRegistered()
