@@ -8,8 +8,6 @@
 
 """Handlers for customizing oauthclient endpoints."""
 
-from __future__ import absolute_import, print_function
-
 from functools import partial, wraps
 
 from flask import current_app, flash, redirect, render_template, request, \
@@ -145,7 +143,7 @@ def signup_handler(remote, *args, **kwargs):
     :returns: Redirect response or the template rendered.
     """
     try:
-        form = create_registrationform(request.form)
+        form = create_registrationform(request.form, oauth_remote_app=remote)
         next_url = base_signup_handler(remote, form, *args, **kwargs)
         if form.is_submitted():
             if next_url:
